Unreleased changes
------------------


Version 0
---------

0.2.2 / 2025-05-07
~~~~~~~~~~~~~~~~~~

* Add limit on ``unix2datetime`` to limit timestamps to 2038/12/31 (limit of POSIX date)


0.2.0 / 2025-04-01
~~~~~~~~~~~~~~~~~~

* Remove template artifacts
* Add detector files (detx/datx) support through ``Detector`` class
* Add PMT paramters files (txt) support through ``PMT_parameters`` class
 
0.1.0 / 2025-04-01
~~~~~~~~~~~~~~~~~~
* Project generated using the cookiecutter template from
  https://git.km3net.de/templates/python-project
